@@ -22,7 +22,7 @@
 #include <gtk/gtk.h>
 #include <hildon/hildon-banner.h>
 #include <hildon/hildon-program.h>
-#include <sqlite3.h>
+//#include <sqlite3.h>
 
 
 gboolean buffer_probe_callback (GstElement * image_sink, GstBuffer * buffer, GstPad * pad);
