@@ -22,7 +22,8 @@
 #include <gtk/gtk.h>
 #include <hildon/hildon-banner.h>
 #include <hildon/hildon-program.h>
-#include <sqlite3.h>
+//#include <sqlite3.h>
+#include <stdio.h>
 #include <gst/gst.h>
 #include <gst/gstbin.h>
 #include <gst/interfaces/xoverlay.h>
@@ -88,6 +89,8 @@ typedef struct {
     GtkWidget *authorlabel;
     GtkWidget *pricelabel;
 
+    GtkWidget *EAN_buffer;
+    
     gchar EAN_text[255];
     gchar title_text[255];
     gchar author_text[255];
@@ -104,19 +107,20 @@ typedef struct {
 
     int scan_in_progress; // see below
     GtkWidget *scan_button; // so we can change the text when it's enabled/disabled
-    sqlite3* db; // the SQLite database
-    GtkWidget *lists_view; // the treeview widget for the list of tables
-    GtkWidget *data_view; // the treeview widget for the data table
-    GtkWidget *search_view; // the treeview widget for the data table
+    GtkWidget *open_button; // so we can change the text when it's enabled/disabled
+    //sqlite3* db; // the SQLite database
+    //GtkWidget *lists_view; // the treeview widget for the list of tables
+    //GtkWidget *data_view; // the treeview widget for the data table
+    //GtkWidget *search_view; // the treeview widget for the data table
 
-    GtkWidget *lists_selection; 
-    GtkWidget *data_selection; 
-    GtkWidget *search_selection; 
+    //GtkWidget *lists_selection; 
+    //GtkWidget *data_selection; 
+    //GtkWidget *search_selection; 
 
     gchar current_data_table_name[255];
 
-    GtkListStore  *lists_store;
-    GtkListStore  *data_store;
+    //GtkListStore  *lists_store;
+    //GtkListStore  *data_store;
 
     int device_type;
     int frame_width;
@@ -128,7 +132,7 @@ typedef struct {
     //char *image_buffer;
 #endif
     
-    
+    FILE* fid;
     
 } AppData;
 
