@@ -29,7 +29,7 @@
 #define WINNING_VOTES 2
 
 
-gboolean analyse_image(unsigned char *data, unsigned char **output);
+gboolean analyse_image(unsigned char *data, unsigned char **output, unsigned char *fourcc, int bpp);
 
 void libdmtx_thread_main();
 
