@@ -25,6 +25,8 @@
 #include <hildon/hildon-banner.h>
 #include <hildon/hildon-program.h>
 #include <hildon/hildon.h>
+#include <hildon/hildon-file-chooser-dialog.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <glib.h>
 #include <ctype.h>
@@ -34,7 +36,7 @@
 
 #include "common.h"
 #include "gui_diablo.h"
-#include "lists.h"
+//#include "lists.h"
 #include "maemo-barcode.h"
 #include "web.h"
 #include "camera_n8x0.h"
@@ -85,7 +87,7 @@ void destroy_gui(GtkWidget *window) {
  * ================================================================================================== */
 
 
-/* Create search results window */
+/* Create search results window 
 GtkWidget *create_search_window() {
     GtkWidget *vbuttonbox, *hbox;
     GtkWidget *button;
@@ -130,16 +132,16 @@ GtkWidget *create_search_window() {
     return hbox;
 }
 
+*/
 
-
-/* Create search dialog */
+/* Create search dialog 
 void search_dialog() {
-    /* In this dialog, allow the user to search from individual tables or all
-       search on individual fields or all
-       use wildcards
-       
-       We need to return the relevant data somehow... how?
-    */
+    // In this dialog, allow the user to search from individual tables or all
+    //  search on individual fields or all
+    //   use wildcards
+    //   
+    //   We need to return the relevant data somehow... how?
+    
 
     GtkWidget *dialog, *hbox;
     GtkWidget *label, *text_entry;
@@ -247,6 +249,8 @@ void search_dialog() {
     gtk_widget_destroy(dialog);
 }
 
+*/
+
 /* Create search results dialog */
 
 
@@ -278,10 +282,18 @@ GtkWidget *create_scan_window() {
     // create the labels and other description stuff which will be on the right hand side of the screen
     strcpy(appdata->EAN_text, "0000000000000");
     //appdata->EANlabel = gtk_label_new (appdata->EAN_text);
+    appdata->EANlabel = gtk_text_view_new(); 
+    appdata->EAN_buffer = gtk_text_buffer_new(NULL);
+    gtk_text_view_set_buffer(appdata->EANlabel, appdata->EAN_buffer);
+    gtk_text_view_set_wrap_mode(appdata->EANlabel, GTK_WRAP_WORD_CHAR);
+    gtk_text_view_set_editable(appdata->EANlabel, TRUE);
+    
+    /*
     appdata->EANlabel = gtk_entry_new();
     gtk_entry_set_text(GTK_ENTRY(appdata->EANlabel), appdata->EAN_text);
     gtk_entry_set_editable(GTK_ENTRY(appdata->EANlabel), FALSE);
-
+    */
+/*
     strcpy(appdata->title_text, "unknown");
     //gtk_label_set_line_wrap(appdata->titlelabel, TRUE); // set line wrapping so we can see all the output
     //gtk_label_set_line_wrap(appdata->titlelabel, TRUE); // set line wrapping so we can see all the output
@@ -300,12 +312,12 @@ GtkWidget *create_scan_window() {
     appdata->pricelabel = gtk_entry_new();
     gtk_entry_set_text(GTK_ENTRY (appdata->pricelabel), appdata->price_text);
     gtk_entry_set_editable(GTK_ENTRY (appdata->pricelabel), FALSE);
-
+*/
     // pack the labels, etc
     gtk_box_pack_start (GTK_BOX (vbox_right), appdata->EANlabel, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox_right), appdata->titlelabel, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox_right), appdata->authorlabel, TRUE, TRUE, 0);
-    gtk_box_pack_start (GTK_BOX (vbox_right), appdata->pricelabel, TRUE, TRUE, 0);
+    //gtk_box_pack_start (GTK_BOX (vbox_right), appdata->titlelabel, TRUE, TRUE, 0);
+    //gtk_box_pack_start (GTK_BOX (vbox_right), appdata->authorlabel, TRUE, TRUE, 0);
+    //gtk_box_pack_start (GTK_BOX (vbox_right), appdata->pricelabel, TRUE, TRUE, 0);
 
     // get rid until the code is working
     //gtk_box_pack_start (GTK_BOX (vbox_right), save_button, TRUE, TRUE, 0);
@@ -321,9 +333,16 @@ GtkWidget *create_scan_window() {
     /* Connect the "clicked" signal of the button to our callback */
     g_signal_connect (G_OBJECT (appdata->scan_button), "clicked", G_CALLBACK (scan_button_pressed), NULL);
 
+    // create the open button
+    appdata->open_button = gtk_button_new_with_label("Open image");
+    /* Connect the "clicked" signal of the button to our callback */
+    g_signal_connect (G_OBJECT (appdata->open_button), "clicked", G_CALLBACK (open_button_pressed), NULL);
+
+
     // start packing these objects
     gtk_box_pack_start (GTK_BOX (vbox_left), appdata->screen, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox_left), appdata->scan_button, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox_left), appdata->open_button, TRUE, TRUE, 0);
 
 
     // now pack the left and right boxes into the overall horizontal box
@@ -339,10 +358,12 @@ void update_scan_window() {
     //gtk_label_set_text((GtkLabel *)appdata->titlelabel, appdata->title_text);
     //gtk_label_set_text((GtkLabel *)appdata->authorlabel, appdata->author_text);
     //gtk_label_set_text((GtkLabel *)appdata->pricelabel, appdata->price_text);
-    gtk_entry_set_text(GTK_ENTRY(appdata->EANlabel), appdata->EAN_text);
-    gtk_entry_set_text(GTK_ENTRY(appdata->titlelabel), appdata->title_text);
-    gtk_entry_set_text(GTK_ENTRY(appdata->authorlabel), appdata->author_text);
-    gtk_entry_set_text(GTK_ENTRY(appdata->pricelabel), appdata->price_text);
+    
+    gtk_text_buffer_set_text(appdata->EAN_buffer, appdata->EAN_text, -1);
+    //gtk_entry_set_text(GTK_ENTRY(appdata->EANlabel), appdata->EAN_text);
+    //gtk_entry_set_text(GTK_ENTRY(appdata->titlelabel), appdata->title_text);
+    //gtk_entry_set_text(GTK_ENTRY(appdata->authorlabel), appdata->author_text);
+    //gtk_entry_set_text(GTK_ENTRY(appdata->pricelabel), appdata->price_text);
 }
 
 
@@ -377,7 +398,144 @@ void scan_button_pressed( GtkWidget *button) {
     }
 }
 
+void open_button_pressed(GtkWidget *button) {
+    GtkWidget* dialog;
+    
+    dialog = hildon_file_chooser_dialog_new(appdata->window, GTK_FILE_CHOOSER_ACTION_OPEN);
+    
+    g_signal_connect(dialog, "response", G_CALLBACK (openfile_cb), NULL);
+        
+    gtk_widget_show_all (dialog);   
+}
 
+
+void openfile_cb (GtkDialog *dialog, gint response, gpointer user_data)
+{
+    char *filename;
+    GdkPixbuf* buf;
+    //char *rgbbuf;
+    char *greybuf;
+    GError *error;
+    int ret;
+    int width, height, rowstride, n_channels;
+    unsigned char *output;
+    BarcodeData *bcdata;
+
+    //struct jpeg_decompress_struct cinfo;
+    //struct jpeg_error_mgr jerr;
+
+    switch (response) {
+        case GTK_RESPONSE_OK:
+            
+            filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+            //fid = fopen(filename, "r");
+            fprintf(appdata->fid, "Open file: %s\n", filename);
+            fflush(appdata->fid);
+            
+            // do something here!
+            
+            
+            // not working, returns error: (null), 3, |
+            {
+                gint width;
+                gint height;
+                GdkPixbufFormat* format = gdk_pixbuf_get_file_info(filename, &width, &height);
+                if(format!=NULL){
+                    fprintf(appdata->fid, "File recognised as %s, width %d, height %d\n", gdk_pixbuf_format_get_name(format), width, height);
+                    fflush(appdata->fid);                
+                }else{
+                    fprintf(appdata->fid, "File format not recognised\n");
+                    fflush(appdata->fid);                
+                }
+            }
+            
+            buf = gdk_pixbuf_new_from_file_at_scale(filename, 640, -1, TRUE, &error);
+            if(buf==NULL){
+                osso_system_note_infoprint(appdata->osso, "Error opening file", NULL);
+                fprintf(appdata->fid, "Error opening file: %s, %d, %s\n", g_quark_to_string(error->domain), error->code, error->message);
+                fflush(appdata->fid);
+                //g_error_free(error);
+                return;
+            }
+            greybuf = gdk_pixbuf_get_pixels(buf);
+
+            if(gdk_pixbuf_get_has_alpha(buf)){
+                fprintf(appdata->fid, "has alpha\n");
+                fflush(appdata->fid);
+                ret = analyse_image(greybuf, &output, "RGBA", gdk_pixbuf_get_n_channels(buf)*gdk_pixbuf_get_bits_per_sample(buf));
+            }else{
+                fprintf(appdata->fid, "no alpha\n");
+                fflush(appdata->fid);
+                ret = analyse_image(greybuf, &output, "RGB", gdk_pixbuf_get_n_channels(buf)*gdk_pixbuf_get_bits_per_sample(buf));
+            }
+            
+            
+            
+            /*
+            //Initialize, open the JPEG and query the parameters 
+            cinfo.err = jpeg_std_error(&jerr);
+            jpeg_create_decompress(&cinfo);
+            jpeg_stdio_src(&cinfo, fid);
+            jpeg_read_header(&cinfo, TRUE);
+            jpeg_start_decompress(&cinfo);
+            
+            // allocate data and read the image as RGBRGBRGBRGB 
+            rgbbuf = malloc(cinfo.output_width * cinfo.output_height * 3);
+            for(int i=0; i < cinfo.output_height; i++)
+            {
+                unsigned char * ptr = rgbbuf + i * 3 * cinfo.output_width;
+                jpeg_read_scanlines(&cinfo, &ptr, 1);
+            }
+            
+            // this image is almost certainly too large
+            // so let's convert it to something else
+            
+            
+            fclose(fid);
+
+            fprintf(appdata->fid, "About to run analyse_image()\n");
+            fflush(appdata->fid);
+            ret = analyse_image(greybuf, &output, "RGB", gdk_pixbuf_get_n_channels(buf)*gdk_pixbuf_get_bits_per_sample(buf));
+            
+            */
+            
+            if(ret!=ZBAR_NONE){
+                osso_system_note_infoprint(appdata->osso, "Decoded barcode contained in file", NULL);
+
+                fprintf(appdata->fid, "Result!\n");
+                fflush(appdata->fid);
+
+                bcdata = malloc(sizeof(BarcodeData)); // struct in common.h
+                bcdata->message_type = ret;
+                bcdata->message_output = g_strdup(output);
+
+                g_idle_add(handle_barcode_data, bcdata);
+                
+            }else{
+                osso_system_note_infoprint(appdata->osso, "Could not find barcode in loaded file", NULL);
+
+                fprintf(appdata->fid, "No result :(\n");
+                fflush(appdata->fid);
+                
+            }
+
+
+            
+            if(output)          
+                free(output);
+                
+            g_free (filename);
+
+            break;
+        default:
+            break; // dialog was cancelled, so do nothing
+    }
+    gtk_widget_destroy(dialog);
+    return;   
+}
+
+
+/*
 void save_button_pressed( GtkWidget *button) {
     // button has been pressed
 
@@ -636,6 +794,7 @@ void save_button_pressed( GtkWidget *button) {
     gtk_widget_destroy(dialog);
 
 }
+*/
 
 /* ==================================================================================================
  *
@@ -643,7 +802,7 @@ void save_button_pressed( GtkWidget *button) {
  *
  * ================================================================================================== */
 
-/* Create database list window contents */
+/* Create database list window contents 
 GtkWidget *create_lists_window() {
     GtkWidget *vbuttonbox, *hbox;
     GtkWidget *button;
@@ -684,12 +843,12 @@ GtkWidget *create_lists_window() {
 
     return hbox;
 }
-
+*/
 
 /* ==================================================================================================
  * lists window callbacks
  * ================================================================================================== */
-
+/*
 // handle clicks on the New List button
 void create_new_list_button() {
     GtkWidget *dialog, *hbox;
@@ -925,7 +1084,7 @@ void delete_list_button() {
 
 }
 
-
+*/
 
 
 /* ==================================================================================================
@@ -934,7 +1093,7 @@ void delete_list_button() {
  *
  * ================================================================================================== */
 
-/* Create list entries (i.e. data) window contents */
+/* Create list entries (i.e. data) window contents 
 GtkWidget *create_data_window() {
     GtkWidget *hbox, *vbuttonbox, *button; //, *view;
     GtkAdjustment *hadjustment;
@@ -993,11 +1152,11 @@ GtkWidget *create_data_window() {
 
     return hbox;
 }
-
+*/
 /* ==================================================================================================
  * Data window callbacks
  * ================================================================================================== */
-
+/*
 void edit_data_button() { // pass it the data in question!
     // create list boxes with the existing data, and a button to click to allow saving changes
 
@@ -1120,10 +1279,10 @@ void edit_data_button() { // pass it the data in question!
     gtk_container_add(GTK_CONTAINER(hbox), text_entry_DATE);
     gtk_container_add(GTK_CONTAINER(GTK_DIALOG (dialog)->vbox), hbox);
 
-    /*
+    
        // this gives us the pretty name for the current database, we might want to know this
-       get_pretty_from_sql_name(sqlite_name, list_name->str);
-    */
+       // get_pretty_from_sql_name(sqlite_name, list_name->str);
+   
 
     // should add two more buttons to this dialog - to perform a web search and update on this information, and to delete the currently selected record
 
@@ -1248,23 +1407,23 @@ void webfill_all_data_button() { // pass it the data in question!
     printf("webfill_all_data_button: select * from %s \n", appdata->current_data_table_name);
     sqlite3_free(command);
     while (get_next_data_row(stmt, &key, EAN, ISBN, title, author, &price, place, &number, &datetime)==SQLITE_ROW) {
-        /*
-        if (lookup_data(EAN, ISBN, title, author, &price, place, &number, &datetime)) {
-            // we've looked up and updated this data
-            // now save it back in the database
-            change_entry(appdata->current_data_table_name, key, EAN, ISBN, title, author, &price, place, &number, &datetime); // should probably error check here too!
-
-            // now refresh the data held in the treeview
-            gtk_list_store_set (appdata->data_store, &iter, COL_KEY, key, COL_EAN, EAN, COL_ISBN, ISBN, COL_TITLE, title, \
-                                COL_AUTHOR, author, COL_PRICE, price, COL_PLACE, place, COL_NUMBER, number, COL_DATE, datetime,-1);
-        } else {
-            // couldn't find this one, so do nothing
-        }
-        */
+        //
+        //if (lookup_data(EAN, ISBN, title, author, &price, place, &number, &datetime)) {
+        //   // we've looked up and updated this data
+        //    // now save it back in the database
+        //    change_entry(appdata->current_data_table_name, key, EAN, ISBN, title, author, &price, place, &number, &datetime); // should probably error check here too!
+        //
+        //    // now refresh the data held in the treeview
+        //    gtk_list_store_set (appdata->data_store, &iter, COL_KEY, key, COL_EAN, EAN, COL_ISBN, ISBN, COL_TITLE, title, \
+        //                        COL_AUTHOR, author, COL_PRICE, price, COL_PLACE, place, COL_NUMBER, number, COL_DATE, datetime,-1);
+        //} else {
+        //    // couldn't find this one, so do nothing
+        //}
+        
     }
     rc=sqlite3_finalize(stmt); //finish_query(stmt);
 }
-
+*/
 
 /* Create scanned book entry window contents */
 /* Create scanned CD entry window contents */
