@@ -22,7 +22,7 @@
 #include <gtk/gtk.h>
 #include <hildon/hildon-banner.h>
 #include <hildon/hildon-program.h>
-#include <sqlite3.h>
+//#include <sqlite3.h>
 
 void initialize_gui(HildonProgram ** program, HildonWindow ** window, int *argc, char ***argv, gchar * app_name);
 void destroy_gui(GtkWidget *window);
@@ -33,6 +33,8 @@ void search_dialog();
 GtkWidget *create_scan_window();
 void update_scan_window();
 void scan_button_pressed( GtkWidget *button);
+void open_button_pressed(GtkWidget *button);
+void openfile_cb (GtkDialog *dialog, gint response, gpointer user_data);
 void save_button_pressed( GtkWidget *button);
 
 GtkWidget *create_lists_window();
