@@ -22,26 +22,26 @@
 #include <gtk/gtk.h>
 #include <hildon/hildon-banner.h>
 #include <hildon/hildon-program.h>
-#include <sqlite3.h>
-
-
-static void set_orientation(const gchar* orientation);
-gboolean device_is_portrait_mode();
-static DBusHandlerResult dbus_handle_mce_message(DBusConnection *con, DBusMessage *msg, gpointer data);
-void orientation_enable_accelerometers();
-void orientation_disable_accelerometers();
-void orientation_init();
-
+//#include <sqlite3.h>
 
 void initialize_gui(HildonProgram ** program, HildonWindow ** window, int *argc, char ***argv, gchar * app_name);
 void destroy_gui(GtkWidget *window);
 
+void orientation_init(void);
+void orientation_enable_accelerators(void);
+void orientation_disable_accelerators(void);
+
+
+
 GtkWidget *create_search_window();
 void search_dialog();
 
 GtkWidget *create_scan_window();
 void update_scan_window();
 void scan_button_pressed( GtkWidget *button);
+void open_button_pressed(GtkWidget *button);
+void openfile_cb (GtkDialog *dialog, gint response, gpointer user_data);
+
 void save_button_pressed( GtkWidget *button);
 
 GtkWidget *create_lists_window();
@@ -57,5 +57,8 @@ GtkWidget *create_info_window(char *EAN);
 
 void webfill_all_data_button();
 void update_scan_window();
+
+
+
 #endif
 
