@@ -30,7 +30,7 @@
 #include "common.h"
 #include "batoo.h"
 #include "maemo-barcode.h"
-#include "lists.h"
+//#include "lists.h"
 
 #ifdef FREMANTLE
 #include "gui_fremantle.h"
@@ -65,14 +65,16 @@ int main (int argc, char **argv) {
     
     appdata = &appdata_obj;
     
-    appdata->lists_store = NULL;
-    appdata->data_store = NULL;
+    //appdata->lists_store = NULL;
+    //appdata->data_store = NULL;
 
     /* Open the database */
-    appdata->db = init_db();
+    //appdata->db = init_db();
 
     //test_db_is_ok();
     get_device_type();
+    
+    appdata->fid = fopen("/home/user/mbarcode.debug", "w+"); // DEBUG
 
 #ifdef USE_ZBAR
     appdata->scanner = zbar_image_scanner_create();
@@ -83,13 +85,16 @@ int main (int argc, char **argv) {
 #endif
 
     printf("About to do osso_initialize()\n");
-    appdata->osso = osso_initialize("org.maemo.mbarcode", "0.0.7", FALSE, NULL);
+    appdata->osso = osso_initialize("org.maemo.mbarcode", "0.0.8", FALSE, NULL);
     if(!appdata->osso){
         printf("OSSO initialisation error\n");
-        close_db();
+        //close_db();
+        fclose(appdata->fid);
         exit(1);
     }
     
+    
+    // this code and the callback below are designed to allow us to receive DBus messages
     result = osso_rpc_set_cb_f(appdata->osso,
                                "org.maemo.mbarcode",
                                "/org/maemo/mbarcode",
@@ -101,11 +106,15 @@ int main (int argc, char **argv) {
         return OSSO_ERROR;
     }
     
+    
     printf("About to do osso_get_sys_dbus_connection()\n");
     
     // http://wiki.maemo.org/Documentation/Maemo_5_Developer_Guide/Using_Data_Sharing/SendVia_Functionality
+#ifdef FREMANTLE    
     appdata->con = osso_get_sys_dbus_connection(appdata->osso);
-    //appdata->con = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
+#else
+    appdata->con = dbus_g_bus_get(DBUS_BUS_SYSTEM, &error);
+#endif
     
     
     /* Initialize and create the GUI */
@@ -205,7 +214,7 @@ gint dbus_req_handler(const gchar * interface, const gchar * method,
                       GArray * arguments, gpointer data,
                       osso_rpc_t * retval)
 {
-    osso_system_note_infoprint(appdata->osso, method, retval);
+    //osso_system_note_infoprint(appdata->osso, method, retval);
     osso_rpc_free_val(retval);
     
     /*
@@ -236,7 +245,8 @@ void notebook_page_change(GtkNotebook *notebook, GtkNotebookPage *page, guint pa
 void shutdown(GtkWidget * widget) {
     destroy_pipeline(widget);
     //free(appdata->image_buffer);
-    close_db();
+    //close_db();
+    fclose(appdata->fid);
     osso_deinitialize(appdata->osso);    
     exit(0);
 }
