@@ -1715,7 +1715,7 @@ int handle_barcode_data(BarcodeData *bcdata) //(char *data, int barcode_type)
     
     // decide what sort of data this is, and decide what we want to do with it
     fprintf(stdout, "Entered handle_barcode_data()\n");
-    if (barcode_type == BARCODE_TYPE_DMTX){
+    if (barcode_type == ZBAR_QRCODE){ //BARCODE_TYPE_DMTX
         // this is a datamatrix barcode
         printf("handle_barcode_Data(): Datamatrix type barcode: %s\n", data);
         if (parse_mixed_barcode_data(data)) //# hand it off to be analysed
@@ -1723,7 +1723,7 @@ int handle_barcode_data(BarcodeData *bcdata) //(char *data, int barcode_type)
             free(bcdata);
             return FALSE;
     }
-    else if (barcode_type == BARCODE_TYPE_1D){
+    else if (barcode_type <= ZBAR_CODE39 && barcode_type >= ZBAR_EAN8){ //(barcode_type == BARCODE_TYPE_1D){
         int type=1; // 0 = not all digits; 1 = all digits; 2 = all digits + X/x
         int i;
         printf("handle_barcode_Data(): 1D type barcode: %s\n", data);
@@ -1766,13 +1766,14 @@ int handle_barcode_data(BarcodeData *bcdata) //(char *data, int barcode_type)
             }else
                 printf("ISBN 10 checksum fail");
         }
+    /*
     }else if (barcode_type == BARCODE_TYPE_QRCODE){
         printf("handle_barcode_Data(): QR code type barcode: %s\n", data);
         if (parse_mixed_barcode_data(data)){ //# hand it off to be analysed
             free(data);
             free(bcdata);
             return FALSE; // return TRUE;
-        }
+        }*/
     }
     printf("handle_barcode_Data(): fallback mixed type barcode: %s\n", data);
     parse_mixed_barcode_data(data); //# hand it off to be analysed
@@ -2158,7 +2159,7 @@ void do_EAN8_lookup(char *data)
 
 
 // this should be a user setting
-int use_web=1;
+int use_web=0;
 
 int handle_ISBN13(char *data)
 {
@@ -2249,6 +2250,14 @@ void signal_barcode_payload(char* barcode, int type)
     DBusMessageIter args; 
     dbus_uint32_t serial;
 
+    // add check for benefit of Diablo users, need to track down the problem here...
+    // I wonder if it has to do with the service file or more likely the .desktop which doesn't
+    // work under Diablo....?
+    if(!appdata->con){
+        fprintf(stderr, "DBus connection failed, debug this!\n"); 
+        return;
+    }
+
     msg = dbus_message_new_signal("/org/maemo/mbarcode", // object name of the signal
          "org.maemo.mbarcode", // interface name of the signal
          "BarcodeDecoded"); // name of the signal
